summaryrefslogtreecommitdiffstats
path: root/misc/scripts/check_ci_log.py
diff options
context:
space:
mode:
Diffstat (limited to 'misc/scripts/check_ci_log.py')
-rwxr-xr-xmisc/scripts/check_ci_log.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/misc/scripts/check_ci_log.py b/misc/scripts/check_ci_log.py
index d024a3e..7abf00e 100755
--- a/misc/scripts/check_ci_log.py
+++ b/misc/scripts/check_ci_log.py
@@ -28,10 +28,10 @@ if (
or file_contents.find("Aborted (core dumped)") != -1
or file_contents.find("terminate called without an active exception") != -1
):
- print("FATAL ERROR: Godot has been crashed.")
+ print("FATAL ERROR: Redot has been crashed.")
sys.exit(52)
# Finding memory leaks in Godot is quite difficult, because we need to take into
# account leaks also in external libraries. They are usually provided without
# debugging symbols, so the leak report from it usually has only 2/3 lines,
# so searching for 5 element - "#4 0x" - should correctly detect the vast
@@ -42,7 +42,7 @@ if file_contents.find("ERROR: LeakSanitizer:") != -1:
print("ERROR: Memory leak was found")
sys.exit(53)
# It may happen that Godot detects leaking nodes/resources and removes them, so
# this possibility should also be handled as a potential error, even if
# LeakSanitizer doesn't report anything
@@ -58,7 +58,7 @@ if file_contents.find("Assertion failed") != -1:
print("ERROR: Assertion failed in project, check execution log for more info")
sys.exit(55)
# For now Godot leaks a lot of rendering stuff so for now we just show info
# about it and this needs to be re-enabled after fixing this memory leaks.
if file_contents.find("were leaked") != -1 or file_contents.find("were never freed") != -1:
@@ -28,10 +28,10 @@ if (
sys.exit(52)
-# Finding memory leaks in Godot is quite difficult, because we need to take into
+# Finding memory leaks in Redot is quite difficult, because we need to take into
# account leaks also in external libraries. They are usually provided without
# debugging symbols, so the leak report from it usually has only 2/3 lines,
@@ -42,7 +42,7 @@ if file_contents.find("ERROR: LeakSanitizer:") != -1:
print("ERROR: Memory leak was found")
sys.exit(53)
-# It may happen that Godot detects leaking nodes/resources and removes them, so
+# It may happen that Redot detects leaking nodes/resources and removes them, so
# this possibility should also be handled as a potential error, even if
# LeakSanitizer doesn't report anything
@@ -58,7 +58,7 @@ if file_contents.find("Assertion failed") != -1:
print("ERROR: Assertion failed in project, check execution log for more info")
sys.exit(55)
-# For now Godot leaks a lot of rendering stuff so for now we just show info
+# For now Redot leaks a lot of rendering stuff so for now we just show info
# about it and this needs to be re-enabled after fixing this memory leaks.
if file_contents.find("were leaked") != -1 or file_contents.find("were never freed") != -1: